#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-typing
version:              0.1.1
visibility:           public
id:                   hslua-typing-0.1.1-L6ScFQ1kJoLIJHwoW5Hjpi
key:                  hslua-typing-0.1.1-L6ScFQ1kJoLIJHwoW5Hjpi
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Type specifiers for Lua.
description:
    Structure to hold detailed type information. The primary
    use-case at this time are auto-generated docs.

category:             Foreign
abi:                  b247fb4d5508bc9c3abb4fe106595f63
exposed:              True
exposed-modules:      HsLua.Typing
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-typing-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-typing-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-typing-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-typing
hs-libraries:         HShslua-typing-0.1.1-L6ScFQ1kJoLIJHwoW5Hjpi
depends:
    base-4.18.2.1 containers-0.6.7
    hslua-core-2.3.2.1-LXQpPSw4OpEHUpcBESWogr
    hslua-marshalling-2.3.2-BBDZ4eUV1LSFOePWJBytfU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-typing/html/hslua-typing.haddock

haddock-html:         /usr/share/doc/haskell-hslua-typing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

